@@ -1,12 +1,14 @@
 import struct
 
 class Codec(object):
-    """ Base class for SARP message encoding/decoding """
+    """
+    Base class for SARP message encoding/decoding
+    """
     def __init__(self, msg_schema):
         self.msg_schema = msg_schema
         fmt_str = '!' + ''.join([self.msg_schema[k] for k in self.msg_schema])
         self.struct = struct.Struct(fmt_str)
-    
+
     def encode(self, msg):
         """
         Args:
